==> haskell-js-jquery-3.3.1-299-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.3.1
id: js-jquery-3.3.1-GWx9hSN0v6MGMCPaJEwJfQ
key: js-jquery-3.3.1-GWx9hSN0v6MGMCPaJEwJfQ
license: MIT
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: f8aff63d6266290ee386b65eade66f2b
exposed: True
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
import-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.3.1-GWx9hSN0v6MGMCPaJEwJfQ
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.3.1-300-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.3.1
id: js-jquery-3.3.1-KVlhFTLCC3nKpSpDTobUsX
key: js-jquery-3.3.1-KVlhFTLCC3nKpSpDTobUsX
license: MIT
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: 562f81b463623637d1d849b13f3379b9
exposed: True
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
import-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.3.1-KVlhFTLCC3nKpSpDTobUsX
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
